<?xml version="1.0" encoding="utf-8" ?>
<!--
 Navigatore rapido di sinistri XML.
 TODO supporto link inter-sinistro in caso di sinistri multipli
 TODO migliorare responsiveness
 -->
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:ns="http://bds.ivass.it/segnalazioni/v1/input"
                xmlns:xs="http://www.w3.org/2001/XMLSchema">
    <xsl:variable name="xsd" select="document('bds_flu_input.xsd')"/>
    <xsl:output
        method="html"
        doctype-system="about:legacy-compat"
        encoding="UTF-8"
        indent="yes" />

    <xsl:template match="ns:segnalazioni">
<html lang="it">
    <head>
        <meta charset="utf-8"/>
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no"/>
        <title><xsl:value-of select="child::comment()"/> - Sinistri XML renderer</title>
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css"
              integrity="sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh"
              crossorigin="anonymous"/>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css"/>
        <style type="text/css">
            #page {
                margin-top: 10px;
            }
            .fa {
            margin-left: 4px;
            }
            .card {
                margin-top: 10px;
            }
            .card:target {
                border-radius: .35em;
                outline: none;
                border: 3px solid red;
                box-shadow: 0 0 10px red;
            }
            .badge-block {
                white-space: normal;
            }
            .flag {
                height: 32px;
                width: 32px;
            }
        </style>
    </head>
    <body>
        <div class="container-fluid" id="page">

            <xsl:for-each select="ns:sinistro">
            <div class="row">
                <div class="col-sm-12">
                    <div class="card sinistro">
                        <div class="card-header">
                            Sinistro <xsl:value-of select="ns:cod-sinistro"/>
                        </div>
                        <div class="card-body">
                            <xsl:apply-templates select="child::comment()" mode="documentation"/>

                            <dl class="row">
                                <xsl:for-each select="*[not(*)]">
                                    <dt class="col-sm-3"><xsl:value-of select="local-name()"/></dt>
                                    <dd class="col-sm-9">
                                        <xsl:value-of select="text()"/>
                                        <xsl:if test="local-name()='tipo-invio-sinistro'">
                                            &#160;
                                            <button class="btn btn-sm btn-dark" type="button" data-toggle="collapse" data-target="#tipoInvioSinistroInfo">
                                                &#128712;
                                            </button>
                                            <div class="collapse" id="tipoInvioSinistroInfo">
                                                <div class="card card-body">
                                                    <xsl:variable name="idTipoInvioSinistro" select="text()"/>
                                                    <xsl:value-of select="$xsd//xs:simpleType[@name='tipoInvioSinistroType']/xs:restriction/xs:enumeration[@value=$idTipoInvioSinistro]/xs:annotation/xs:documentation" disable-output-escaping="yes"/>
                                                </div>
                                            </div>
                                        </xsl:if>
                                        <xsl:if test="local-name()='autorita'">
                                            &#160;
                                            <span class="badge badge-info">
                                                <xsl:variable name="idAutorita" select="text()"/>
                                                <xsl:value-of select="$xsd//xs:simpleType[@name='autoritaType']/xs:restriction/xs:enumeration[@value=$idAutorita]/xs:annotation/xs:documentation"/>
                                            </span>
                                        </xsl:if>
                                    </dd>
                                </xsl:for-each>
                                <xsl:apply-templates select="ns:luogo-accadimento" mode="luogoSinistro"/>
                                <xsl:apply-templates select="ns:altre-figure" mode="figuraLink"/>
                            </dl>

                            <div class="row">
                                <div class="col-sm-12">
                                    <div class="card-group">
                                        <xsl:for-each select="ns:soggetti/ns:soggetto">
                                        <div class="card soggetto">
                                            <xsl:attribute name="id">soggetto-<xsl:value-of select="ns:id-soggetto"/></xsl:attribute>
                                            <div class="card-header bg-dark text-white">
                                                Soggetto <xsl:value-of select="ns:id-soggetto"/>
                                                <xsl:if test="ns:tax-italia">
                                                    &#160;<img class="flag" src="https://emojipedia-us.s3.dualstack.us-west-1.amazonaws.com/thumbs/120/whatsapp/238/flag-for-italy_1f1ee-1f1f9.png"/>
                                                </xsl:if>
                                                <xsl:if test="ns:tax-estero">
                                                &#160;<img class="flag" src="https://emojipedia-us.s3.dualstack.us-west-1.amazonaws.com/thumbs/120/whatsapp/238/earth-globe-europe-africa_1f30d.png"/>
                                                </xsl:if>
                                            </div>
                                            <div class="card-body">
                                                <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                                <dl class="row">
                                                    <xsl:apply-templates select="ns:tax-italia"/>
                                                    <xsl:apply-templates select="ns:tax-estero"/>
                                                    <xsl:for-each select="*[not(*)]">
                                                        <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
                                                        <dd class="col-sm-8"><xsl:value-of select="text()"/></dd>
                                                    </xsl:for-each>
                                                    <xsl:apply-templates select="ns:luogo-nascita" mode="luogoSoggetto"/>
                                                    <xsl:apply-templates select="ns:luogo-sede" mode="luogoSoggetto"/>
                                                </dl>

                                                <xsl:if test="ns:danni">
                                                    <div class="row">
                                                        <div class="col-sm-12">
                                                            <div class="card danno-soggetto">
                                                                <div class="card-header bg-danger text-white">
                                                                    Danno
                                                                </div>
                                                                <div class="card-body">
                                                                    <xsl:apply-templates select="ns:danni/child::comment()" mode="documentation"/>

                                                                    <dl class="row">
                                                                        <xsl:for-each select="ns:danni/ns:lesioni/ns:lesione">
                                                                            <dt class="col-sm-4">lesione-<xsl:value-of select="position()"/></dt>
                                                                            <dd class="col-sm-8">
                                                                                <abbr>
                                                                                    <xsl:attribute name="title" xml:space="default">Natura: <xsl:variable name="idNaturaLesione" select="ns:natura"/><xsl:value-of
                                                                                        select="$xsd//xs:simpleType[@name='naturaLesioneType']/xs:restriction/xs:enumeration[@value=$idNaturaLesione]/xs:annotation/xs:documentation"/></xsl:attribute>
                                                                                    <xsl:value-of select="ns:natura"/>
                                                                                </abbr>
                                                                                /
                                                                                <abbr>
                                                                                    <xsl:attribute name="title">Sede: <xsl:variable name="idSedeLesione"
                                                                                                                                    select="ns:sede"/><xsl:value-of
                                                                                        select="$xsd//xs:simpleType[@name='sedeLesioneType']/xs:restriction/xs:enumeration[@value=$idSedeLesione]/xs:annotation/xs:documentation"/></xsl:attribute>
                                                                                    <xsl:value-of select="ns:sede"/>
                                                                                </abbr>
                                                                            </dd>
                                                                        </xsl:for-each>
                                                                        <xsl:for-each select="ns:danni/*[not(*)]">
                                                                            <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
                                                                            <dd class="col-sm-8">
                                                                                <xsl:choose>
                                                                                    <xsl:when test="local-name()='pronto-soccorso'">
                                                                                        <xsl:choose>
                                                                                            <xsl:when test="text()">
                                                                                                <xsl:value-of select="text()"/>
                                                                                            </xsl:when>
                                                                                            <xsl:otherwise>
                                                                                                (sconosciuto)
                                                                                            </xsl:otherwise>
                                                                                        </xsl:choose>
                                                                                    </xsl:when>
                                                                                    <xsl:otherwise>
                                                                                        <xsl:value-of select="text()"/>
                                                                                    </xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </dd>
                                                                        </xsl:for-each>
                                                                    </dl>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </xsl:if>
                                            </div>
                                        </div>
                                        <xsl:if test="position() = 2">
                                            <div class="w-100 d-none d-sm-block d-md-none"><!-- wrap every 2 on sm--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 3">
                                            <div class="w-100 d-none d-md-block d-lg-none"><!-- wrap every 3 on md--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 4">
                                            <div class="w-100 d-none d-sm-block d-md-none"><!-- wrap every 2 on sm--></div>
                                            <div class="w-100 d-none d-lg-block d-xl-none"><!-- wrap every 4 on lg--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 5">
                                            <div class="w-100 d-none d-xl-block"><!-- wrap every 5 on xl--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 6">
                                            <div class="w-100 d-none d-sm-block d-md-none"><!-- wrap every 2 on sm--></div>
                                            <div class="w-100 d-none d-md-block d-lg-none"><!-- wrap every 3 on md--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 8">
                                            <div class="w-100 d-none d-sm-block d-md-none"><!-- wrap every 2 on sm--></div>
                                            <div class="w-100 d-none d-lg-block d-xl-none"><!-- wrap every 4 on lg--></div>
                                        </xsl:if>
                                        <xsl:if test="position() = 9">
                                            <div class="w-100 d-none d-md-block d-lg-none"><!-- wrap every 3 on md--></div>
                                        </xsl:if>
                                        </xsl:for-each>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-sm-12">
                                    <div class="card-group">
                                    <xsl:for-each select="ns:veicoli/ns:veicolo">
                                    <div class="card veicolo">
                                        <xsl:attribute name="id">veicolo-<xsl:value-of select="ns:id-veicolo"/></xsl:attribute>
                                        <div class="card-header bg-success text-white">
                                            Veicolo <xsl:value-of select="ns:id-veicolo"/>
                                        </div>
                                        <div class="card-body">
                                            <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                            <dl class="row">
                                                <dt class="col-sm-4">tipo-targa</dt>
                                                <dd class="col-sm-8">
                                                    <xsl:value-of select="ns:targa/@tipo"/>
                                                    &#160;
                                                    <span class="badge badge-info">
                                                        <xsl:variable name="idTipoTarga" select="ns:targa/@tipo"/>
                                                        <xsl:value-of select="$xsd//xs:simpleType[@name='tipoTargaType']/xs:restriction/xs:enumeration[@value=$idTipoTarga]/xs:annotation/xs:documentation"/>
                                                    </span>
                                                </dd>

                                                <xsl:for-each select="*[not(*)]">
                                                    <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
                                                    <dd class="col-sm-8">

                                                        <xsl:choose>
                                                            <xsl:when test="local-name()='coerenza-perizia'">
                                                                <abbr>
                                                                    <xsl:attribute name="title" xml:space="default"><xsl:variable name="idCoerenzaPerizia" select="text()"/><xsl:value-of
                                                                        select="$xsd//xs:simpleType[@name='coerenzaDannoPeriziaType']/xs:restriction/xs:enumeration[@value=$idCoerenzaPerizia]/xs:annotation/xs:documentation"/></xsl:attribute>
                                                                    <xsl:value-of select="text()"/>
                                                                </abbr>
                                                            </xsl:when>

                                                            <xsl:when test="local-name()='copertura-polizza'">
                                                                <abbr>
                                                                    <xsl:attribute name="title" xml:space="default"><xsl:variable name="idCoerenzaPolizza" select="text()"/><xsl:value-of
                                                                        select="$xsd//xs:simpleType[@name='coperturaPolizzaType']/xs:restriction/xs:enumeration[@value=$idCoerenzaPolizza]/xs:annotation/xs:documentation"/></xsl:attribute>
                                                                    <xsl:value-of select="text()"/>
                                                                </abbr>
                                                            </xsl:when>

                                                            <xsl:otherwise>
                                                                <xsl:value-of select="text()"/>
                                                                <xsl:if test="local-name()='tipo-veicolo'">
                                                                    &#160;
                                                                    <span class="badge badge-info">
                                                                        <xsl:variable name="idTipoVeicolo" select="text()"/>
                                                                        <xsl:value-of select="$xsd//xs:simpleType[@name='tipoVeicoloType']/xs:restriction/xs:enumeration[@value=$idTipoVeicolo]/xs:annotation/xs:documentation"/>
                                                                    </span>
                                                                </xsl:if>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                    </dd>
                                                </xsl:for-each>

                                                <xsl:for-each select="ns:danni-veicolo/ns:cod-danno">
                                                    <dt class="col-sm-4">danno-<xsl:value-of select="position()"/></dt>
                                                    <dd class="col-sm-8">
                                                        <abbr>
                                                            <xsl:attribute name="title" xml:space="default"><xsl:variable name="idCodDannoVeicolo" select="text()"/><xsl:value-of
                                                                select="$xsd//xs:simpleType[@name='codDannoVeicoloType']/xs:restriction/xs:enumeration[@value=$idCodDannoVeicolo]/xs:annotation/xs:documentation"/></xsl:attribute>
                                                            <xsl:value-of select="text()"/>
                                                        </abbr>
                                                    </dd>
                                                </xsl:for-each>
                                            </dl>
                                        </div>
                                    </div>
                                    </xsl:for-each>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-sm-12">
                                    <div class="card-group">
                                        <xsl:for-each select="ns:collegamenti/ns:collegamento">
                                        <div class="card collegamento">
                                            <div class="card-header bg-info text-white">
                                                Collegamento tra soggetto
                                                <xsl:choose>
                                                    <xsl:when test="ns:id-soggetto">
                                                        <a class="badge badge-dark text-white"><xsl:attribute name="href">#soggetto-<xsl:value-of select="ns:id-soggetto"
                                                        /></xsl:attribute><xsl:value-of select="ns:id-soggetto"/></a>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        ignoto
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                e veicolo
                                                <a class="badge badge-success text-white"><xsl:attribute name="href">#veicolo-<xsl:value-of select="ns:id-veicolo"
                                                /></xsl:attribute><xsl:value-of select="ns:id-veicolo"/></a>
                                            </div>
                                            <div class="card-body">
                                                <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                                <dl class="row">
                                                    <xsl:for-each select="*[not(*)]">
                                                        <dt class="col-sm-6"><xsl:value-of select="local-name()"/></dt>
                                                        <dd class="col-sm-6"><xsl:value-of select="text()"/>

                                                            <xsl:if test="local-name()='causale'">
                                                                <xsl:variable name="causaleCollegamentoLink">causaleCollegamentoLink-<xsl:value-of select="count(../preceding-sibling::ns:collegamento) + 1"/></xsl:variable>
                                                                &#160;
                                                                <button class="btn btn-sm btn-dark" type="button" data-toggle="collapse">
                                                                    <xsl:attribute name="data-target">#<xsl:value-of select="$causaleCollegamentoLink"/></xsl:attribute>
                                                                    &#128712;
                                                                </button>
                                                                <div class="collapse">
                                                                    <xsl:attribute name="id"><xsl:value-of select="$causaleCollegamentoLink"/></xsl:attribute>
                                                                    <div class="card card-body">
                                                                        <xsl:variable name="idCausale" select="text()"/>
                                                                        <xsl:value-of select="$xsd//xs:simpleType[@name='relCausaleTrattazioneType']/xs:restriction/xs:enumeration[@value=$idCausale]/xs:annotation/xs:documentation" disable-output-escaping="yes"/>
                                                                    </div>
                                                                </div>
                                                            </xsl:if>

                                                        </dd>
                                                    </xsl:for-each>

                                                    <xsl:apply-templates select="ns:altre-figure" mode="figuraLink"/>
                                                </dl>

                                                <xsl:for-each select="ns:ruolo">
                                                    <div class="row">
                                                        <div class="col-sm-12">
                                                            <div class="card danno-partita">
                                                                <div class="card-header bg-dark text-white">
                                                                    Ruolo: <xsl:value-of select="@tipo"/>
                                                                </div>
                                                                <div class="card-body">
                                                                    <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                                                    <dl class="row">
                                                                        <xsl:for-each select="*[not(*)]">
                                                                            <dt class="col-sm-6"><xsl:value-of select="local-name()"/></dt>
                                                                            <dd class="col-sm-6"><xsl:value-of select="text()"/>

                                                                                <xsl:if test="local-name()='causale'">
                                                                                    <xsl:variable name="causaleCollegamentoLink">causaleCollegamentoLink-<xsl:value-of select="count(../preceding-sibling::ns:collegamento) + 1"/></xsl:variable>
                                                                                    &#160;
                                                                                    <button class="btn btn-sm btn-dark" type="button" data-toggle="collapse">
                                                                                        <xsl:attribute name="data-target">#<xsl:value-of select="$causaleCollegamentoLink"/></xsl:attribute>
                                                                                        &#128712;
                                                                                    </button>
                                                                                    <div class="collapse">
                                                                                        <xsl:attribute name="id"><xsl:value-of select="$causaleCollegamentoLink"/></xsl:attribute>
                                                                                        <div class="card card-body">
                                                                                            <xsl:variable name="idCausale" select="text()"/>
                                                                                            <xsl:value-of select="$xsd//xs:simpleType[@name='relCausaleTrattazioneType']/xs:restriction/xs:enumeration[@value=$idCausale]/xs:annotation/xs:documentation" disable-output-escaping="yes"/>
                                                                                        </div>
                                                                                    </div>
                                                                                </xsl:if>

                                                                            </dd>
                                                                        </xsl:for-each>

                                                                        <xsl:apply-templates select="ns:altre-figure" mode="figuraLink"/>
                                                                    </dl>

                                                                    <xsl:for-each select="ns:danni/ns:danno">
                                                                        <div class="row">
                                                                            <div class="col-sm-12">
                                                                                <div class="card danno-partita">
                                                                                    <div class="card-header bg-danger text-white">
                                                                                        Danno per
                                                                                        <span class="badge badge-info">
                                                                                            <xsl:variable name="idTipoDanno" select="@tipo"/>
                                                                                            <xsl:value-of select="$xsd//xs:simpleType[@name='tipoDannoType']/xs:restriction/xs:enumeration[@value=$idTipoDanno]/xs:annotation/xs:documentation"/>
                                                                                        </span>

                                                                                    </div>
                                                                                    <div class="card-body">
                                                                                        <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                                                                        <dl class="row">
                                                                                            <xsl:for-each select="*[not(*)]">
                                                                                                <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
                                                                                                <dd class="col-sm-8">
                                                                                                    <xsl:value-of select="text()"/>
                                                                                                    <xsl:if test="local-name()='tipo-operazione'">
                                                                                                        &#160;
                                                                                                        <span class="badge badge-info">
                                                                                                            <xsl:variable name="idTipoOperazione" select="text()"/>
                                                                                                            <xsl:value-of select="$xsd//xs:simpleType[@name='relTipoOperazioneType']/xs:restriction/xs:enumeration[@value=$idTipoOperazione]/xs:annotation/xs:documentation"/>
                                                                                                        </span>
                                                                                                    </xsl:if>
                                                                                                </dd>
                                                                                            </xsl:for-each>
                                                                                        </dl>

                                                                                        <xsl:for-each select="ns:pagamenti/ns:pagamento">
                                                                                            <div class="row">
                                                                                                <div class="col-sm-12">
                                                                                                    <div class="card pagamento">
                                                                                                        <div class="card-header bg-primary text-white">
                                                                                                            Pagamento #<xsl:value-of select="position()"/> a
                                                                                                            <a class="badge badge-dark text-white"><xsl:attribute name="href">#soggetto-<xsl:value-of select="ns:beneficiario"
                                                                                                            /></xsl:attribute><xsl:value-of select="ns:beneficiario"/></a>
                                                                                                        </div>
                                                                                                        <div class="card-body">
                                                                                                            <xsl:apply-templates select="child::comment()" mode="documentation"/>

                                                                                                            <dl class="row">
                                                                                                                <dt class="col-sm-4">valuta</dt>
                                                                                                                <dd class="col-sm-8"><xsl:value-of select="ns:importo/@valuta"/></dd>
                                                                                                                <xsl:for-each select="*[not(*)]">
                                                                                                                    <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
                                                                                                                    <dd class="col-sm-8"><xsl:value-of select="text()"/></dd>
                                                                                                                </xsl:for-each>
                                                                                                            </dl>
                                                                                                        </div>
                                                                                                    </div>
                                                                                                </div>
                                                                                            </div>
                                                                                        </xsl:for-each>

                                                                                    </div>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </xsl:for-each>

                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </xsl:for-each>

                                            </div>
                                        </div>
                                    </xsl:for-each>
                                    </div>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </div>
            </xsl:for-each>

        </div>

        <script src="https://code.jquery.com/jquery-3.4.1.slim.min.js"
                integrity="sha384-J6qa4849blE2+poT4WnyKhv5vZF5SrPo0iEjwBvKU7imGFAV0wwj1yYfoRSJoZ+n"
                crossorigin="anonymous"/>
        <script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.0/dist/umd/popper.min.js"
                integrity="sha384-Q6E9RHvbIyZFJoft+2mJbHaEWldlvI9IOYy5n3zV9zzTtmI3UksdQRVvoxMfooAo"
                crossorigin="anonymous"/>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/js/bootstrap.min.js"
                integrity="sha384-wfSDF2E50Y2D1uUdj0O3uMBJnjuUD4Ih7YwaYd1iqfktj0Uod8GCExl3Og8ifwB6"
                crossorigin="anonymous"/>

    </body>
</html>
    </xsl:template>

    <xsl:template match="ns:luogo-accadimento" mode="luogoSinistro">
        <dt class="col-sm-3"><xsl:value-of select="local-name()"/></dt>
        <dd class="col-sm-9">
            <xsl:apply-templates select="ns:italia/ns:cod-comune"/>
            <xsl:apply-templates select="ns:italia/ns:cod-provincia"/>
            <xsl:apply-templates select="ns:estero/ns:cod-paese"/>
            <xsl:apply-templates select="ns:estero/ns:luogo"/>
            <xsl:apply-templates select="ns:coordinate"/>
        </dd>
    </xsl:template>

    <xsl:template match="ns:*" mode="luogoSoggetto">
        <dt class="col-sm-4"><xsl:value-of select="local-name()"/></dt>
        <dd class="col-sm-8">
            <xsl:apply-templates select="ns:italia/ns:cod-comune"/>
            <xsl:apply-templates select="ns:italia/ns:cod-provincia"/>
            <xsl:apply-templates select="ns:estero/ns:cod-paese"/>
            <xsl:apply-templates select="ns:estero/ns:luogo"/>
        </dd>
    </xsl:template>

    <xsl:template match="ns:italia/ns:cod-comune">
        <abbr title="Comune"><xsl:value-of select="."/></abbr>
    </xsl:template>

    <xsl:template match="ns:italia/ns:cod-provincia">
        (<abbr title="Provincia"><xsl:value-of select="."/></abbr>)
    </xsl:template>

    <xsl:template match="ns:estero/ns:cod-paese">
        <abbr title="Paese"><xsl:value-of select="."/></abbr>
    </xsl:template>

    <xsl:template match="ns:estero/ns:luogo">
        (<abbr title="Luogo"><xsl:value-of select="."/></abbr>)
    </xsl:template>

    <xsl:template match="ns:coordinate">
        geo:<xsl:value-of select="ns:latitudine"/>,<xsl:value-of select="ns:longitudine"/>
        <a>
            <xsl:attribute name="href">https://maps.google.com/?ll=<xsl:value-of select="ns:latitudine"/>,<xsl:value-of select="ns:longitudine"/>&amp;q=<xsl:value-of select="ns:latitudine"/>,<xsl:value-of select="ns:longitudine"/>&amp;z=15</xsl:attribute>
            <xsl:attribute name="target">_blank</xsl:attribute>
            <i class="fa fa-external-link"/>
        </a>
    </xsl:template>

    <xsl:template match="ns:tax-italia">
        <dt class="col-sm-4">codice-fiscale</dt>
        <dd class="col-sm-8"><xsl:value-of select="ns:codice-fiscale"/></dd>
        <dt class="col-sm-4">partita-iva</dt>
        <dd class="col-sm-8"><xsl:value-of select="ns:partita-iva"/></dd>
    </xsl:template>

    <xsl:template match="ns:tax-estero">
        <dt class="col-sm-4">cod-paese</dt>
        <dd class="col-sm-8"><xsl:value-of select="ns:cod-paese"/></dd>
        <dt class="col-sm-4">vat-id</dt>
        <dd class="col-sm-8"><xsl:value-of select="ns:vat-id"/></dd>
    </xsl:template>

    <xsl:template match="ns:altre-figure" mode="figuraLink">
        <dt class="col-sm-3">altre-figure</dt>
        <dd class="col-sm-9">
            <xsl:for-each select="ns:figura">
                <a class="badge badge-warning badge-block"><xsl:attribute name="href">#soggetto-<xsl:value-of select="text()"
                /></xsl:attribute><xsl:value-of select="text()"/> -
                <xsl:variable name="idTipoFigura" select="@tipo"/><xsl:value-of
                        select="$xsd//xs:simpleType[@name='tipoFiguraType']/xs:restriction/xs:enumeration[@value=$idTipoFigura]/xs:annotation/xs:documentation"
                /></a>&#160;
            </xsl:for-each>
        </dd>
    </xsl:template>

    <xsl:template match="child::comment()" mode="documentation">
        <div class="row">
            <div class="col-sm-12">
                <div class="alert alert-info">
                    <!-- ATTENZIONE disable-output-escaping non funziona su Firefox! -->
                    <xsl:value-of select="." disable-output-escaping="yes"/>
                </div>
            </div>
        </div>
    </xsl:template>

</xsl:stylesheet>
