<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema">
    <!-- TODO key/keyRef -->
    <!-- TODO documentare o migliorare uso di choice (e relativi min/max occurs) -->

    <xsl:output
        method="html"
        doctype-system="about:legacy-compat"
        omit-xml-declaration="yes"
        encoding="UTF-8"
        indent="yes" />

    <xsl:template match="/">
        <html lang="it">
            <head>
                <meta charset="utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no"/>
                <title>Dizionario dati XML</title>
                <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css"
                      integrity="sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh"
                      crossorigin="anonymous"/>
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css"/>
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/prism/1.22.0/themes/prism.min.css" integrity="sha512-tN7Ec6zAFaVSG3TpNAKtk4DOHNpSwKHxxrsiw4GHKESGPs5njn/0sMCUMl2svV4wo4BK/rCP7juYz+zx+l6oeQ==" crossorigin="anonymous" />
                <style type="text/css">
                    #page {
                        margin-top: 10px;
                    }
                    .fa {
                        margin-left: 4px;
                    }
                    .minirow th {
                        padding-top: 2px;
                        padding-bottom: 2px;
                    }
                    dt {
                        font-weight: normal;
                    }
                    dt abbr {
                        font-style: italic;
                        text-decoration: underline dotted;
                    }
                </style>
            </head>
            <body>
                <div class="container" id="page">
                    <xsl:apply-templates />
                </div>

                <script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.22.0/prism.min.js"
                        integrity="sha512-9+422Bs3A87UkWfp+qV80Nfv9arhbCXKY1rxrF2seorI36mIIstMiuBfyKLF1yH1nnzQkEWq2xrzT4XU3Z+vrA=="
                        crossorigin="anonymous"/>
                <script src="https://cdnjs.cloudflare.com/ajax/libs/prism/1.22.0/components/prism-xml-doc.min.js"
                        integrity="sha512-7UKWE2rgzbPpx1Yu/BPH7bHTHiIjheYAtyVQUxAjyBjet5956cCO8cFZbMpMkwHt6U7Eg1PciDXNTsGt4Dz33g=="
                        crossorigin="anonymous"/>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="xsd:annotation/xsd:appinfo">
        <h6>Esempio</h6>
        <pre><code class="language-xml"><xsl:value-of select="."/></code></pre>
    </xsl:template>

    <xsl:template match="xsd:annotation/xsd:documentation">
        <xsl:apply-templates select="* | text()" mode="html"/>
    </xsl:template>

    <xsl:template match="xsd:schema/xsd:element">
        <table class="table table-bordered table-hover">
            <tr>
                <th>Elemento radice</th>
                <td><xsl:value-of select="@name" /></td>
            </tr>
            <tr>
                <th>Namespace</th>
                <td><code><xsl:value-of select="/xsd:schema/@targetNamespace"/></code></td>
            </tr>
            <tr>
                <th>Tipo</th>
                <td><xsl:apply-templates select="@type"/></td>
            </tr>
            <tr>
                <th>Descrizione</th>
                <td><xsl:apply-templates select="xsd:annotation/xsd:documentation"/></td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="xsd:choice">
        <tr class="minirow">
            <th colspan="4">
                <code>&lt;choice&gt;</code> &#160;
                <span class="text-muted">
                    (cardinalità: <xsl:choose><xsl:when test="../@minOccurs"><xsl:value-of select="../@minOccurs" /></xsl:when><xsl:otherwise>1</xsl:otherwise></xsl:choose> .. <xsl:choose><xsl:when test="../@maxOccurs"><xsl:value-of select="../@maxOccurs" /></xsl:when><xsl:otherwise>1</xsl:otherwise></xsl:choose>)
                </span>
            </th>
        </tr>
        <xsl:apply-templates select="xsd:element|xsd:sequence|xsd:choice|xsd:all" />
        <tr class="minirow">
            <th colspan="4">
                <code>&lt;/choice&gt;</code>
            </th>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:choice/xsd:sequence">
        <tr class="minirow">
            <th colspan="4">
                <code>&lt;sequence&gt;</code> &#160;
                <span class="text-muted">
                    (cardinalità: <xsl:choose><xsl:when test="../@minOccurs"><xsl:value-of select="../@minOccurs" /></xsl:when><xsl:otherwise>1</xsl:otherwise></xsl:choose> .. <xsl:choose><xsl:when test="../@maxOccurs"><xsl:value-of select="../@maxOccurs" /></xsl:when><xsl:otherwise>1</xsl:otherwise></xsl:choose>)
                </span>
            </th>
        </tr>
        <xsl:apply-templates select="xsd:element|xsd:sequence|xsd:choice|xsd:all" />
        <tr class="minirow">
            <th colspan="4">
                <code>&lt;/sequence&gt;</code> &#160;
            </th>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:element">
        <tr>
            <td>
                <xsl:value-of select="@name" />
            </td>
            <td>
                <xsl:apply-templates select="@type"/>
            </td>
            <td>
                <xsl:choose>
                    <xsl:when test="@minOccurs">
                        <xsl:value-of select="@minOccurs" />
                    </xsl:when>
                    <xsl:otherwise>
                        1
                    </xsl:otherwise>
                </xsl:choose>
                ..
                <xsl:choose>
                    <xsl:when test="@maxOccurs">
                        <xsl:value-of select="@maxOccurs" />
                    </xsl:when>
                    <xsl:otherwise>
                        1
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td>
                <xsl:apply-templates select="xsd:annotation/xsd:documentation"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:complexType">
        <h2>
            <xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
            <a><xsl:attribute name="href">#<xsl:value-of select="@name"/></xsl:attribute><xsl:value-of select="@name"/></a>
            &#160;<span class="badge badge-secondary"><xsl:value-of select="local-name()"/></span>
        </h2>
        <p><xsl:apply-templates select="xsd:annotation/xsd:documentation"/></p>
        <xsl:apply-templates select="xsd:annotation/xsd:appinfo"/>

        <xsl:if test="xsd:attribute">
            <h5>Attributi</h5>
            <table class="table table-striped table-bordered table-hover">
                <tr>
                    <th>Nome</th>
                    <th>Tipo</th>
                    <th>Uso</th>
                    <th>Descrizione</th>
                </tr>

                <xsl:apply-templates select="xsd:attribute" />
            </table>
        </xsl:if>

        <xsl:choose>
            <xsl:when test="xsd:simpleContent">
                <xsl:apply-templates select="xsd:simpleContent/xsd:restriction"/>
                <xsl:apply-templates select="xsd:simpleContent/xsd:extension"/>
            </xsl:when>

            <xsl:when test="xsd:sequence|xsd:choice|xsd:all">
                <h5>Elementi</h5>
                <table class="table table-striped table-bordered table-hover">
                    <tr>
                        <th>Nome</th>
                        <th>Tipo</th>
                        <th>Cardinalità</th>
                        <th>Descrizione</th>
                    </tr>

                    <xsl:apply-templates select="xsd:sequence|xsd:choice|xsd:all" />
                </table>
            </xsl:when>

            <xsl:when test="xsd:complexContent">
                <xsl:apply-templates select="xsd:complexContent/xsd:extension"/>
                <xsl:apply-templates select="xsd:complexContent/xsd:restriction"/>
            </xsl:when>
        </xsl:choose>

    </xsl:template>

    <xsl:template match="xsd:simpleType">
        <h2>
            <xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
            <a><xsl:attribute name="href">#<xsl:value-of select="@name"/></xsl:attribute><xsl:value-of select="@name"/></a>
            &#160;<span class="badge badge-secondary"><xsl:value-of select="local-name()"/></span>
        </h2>
        <p><xsl:apply-templates select="xsd:annotation/xsd:documentation"/></p>

        <xsl:apply-templates select="xsd:restriction|xsd:extension|xsd:union"/>
    </xsl:template>

    <xsl:template match="xsd:attribute">
        <tr>
            <td>
                <xsl:value-of select="@name"/>
            </td>
            <td>
                <xsl:apply-templates select="@type"/>
            </td>
            <td>
                <xsl:choose>
                    <xsl:when test="@use"><xsl:value-of select="@use"/></xsl:when>
                    <xsl:otherwise>optional</xsl:otherwise>
                </xsl:choose>
            </td>
            <td>
                <xsl:apply-templates select="xsd:annotation/xsd:documentation"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:extension">
        <h5>Estensione</h5>
        <table class="table table-bordered table-hover">
            <tr>
                <th>base</th>
                <td><xsl:apply-templates select="@base"/></td>
            </tr>
        </table>

        <xsl:if test="xsd:attribute">
            <h5>Attributi</h5>
            <table class="table table-striped table-bordered table-hover">
                <tr>
                    <th>Nome</th>
                    <th>Tipo</th>
                    <th>Uso</th>
                    <th>Descrizione</th>
                </tr>

                <xsl:apply-templates select="xsd:attribute" />
            </table>
        </xsl:if>

        <xsl:if test="xsd:sequence|xsd:choice|xsd:all">
            <h5>Elementi</h5>
            <table class="table table-striped table-bordered table-hover">
                <tr>
                    <th>Nome</th>
                    <th>Tipo</th>
                    <th>Cardinalità</th>
                    <th>Descrizione</th>
                </tr>

                <xsl:apply-templates select="xsd:sequence|xsd:choice|xsd:all" />
            </table>
        </xsl:if>

    </xsl:template>

    <xsl:template match="xsd:union">
        <h5>Unione</h5>
        <table class="table table-bordered table-hover">
            <tr>
                <th>memberTypes</th>
                <td><xsl:apply-templates select="@memberTypes"/></td>
            </tr>
        </table>
        <xsl:apply-templates select="xsd:simpleType/xsd:restriction|xsd:simpleType/xsd:extension"/>
    </xsl:template>

    <xsl:template match="xsd:restriction">
        <h5>Restrizione</h5>
        <table class="table table-bordered table-hover">
            <tr>
                <th>base</th>
                <td><xsl:apply-templates select="@base"/></td>
            </tr>
            <xsl:apply-templates select="xsd:pattern|xsd:minLength|xsd:maxLength|xsd:length|xsd:maxInclusive|xsd:minInclusive|xsd:minExclusive|xsd:maxExclusive|xsd:fractionDigits|xsd:totalDigits"/>
        </table>

        <xsl:if test="xsd:enumeration">
            <h5>Enumerazione</h5>
            <table class="table table-striped table-bordered table-hover">
                <tr>
                    <th>Valore</th>
                    <th>Descrizione</th>
                </tr>

                <xsl:apply-templates select="xsd:enumeration" />
            </table>
        </xsl:if>
    </xsl:template>

    <xsl:template match="xsd:minLength|xsd:maxLength|xsd:length|xsd:maxInclusive|xsd:minInclusive|xsd:minExclusive|xsd:maxExclusive|xsd:fractionDigits|xsd:totalDigits">
        <tr>
            <th><xsl:value-of select="local-name()"/></th>
            <td><xsl:value-of select="@value"/></td>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:pattern">
        <tr>
            <th><xsl:value-of select="local-name()"/></th>
            <td><code><xsl:value-of select="@value"/></code></td>
        </tr>
    </xsl:template>

    <xsl:template match="xsd:enumeration">
        <tr>
            <td>
                <xsl:value-of select="@value"/>
            </td>
            <td>
                <xsl:apply-templates select="xsd:annotation/xsd:documentation"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="@type|@base|@memberTypes">
        <xsl:variable name="isPrimitiveType" select="starts-with(., 'xs:')"/>
        <a>
            <xsl:attribute name="href"><xsl:choose><xsl:when
                test="$isPrimitiveType">http://www.w3.org/TR/xmlschema-2/#<xsl:value-of
                select="substring(., 4)"/></xsl:when><xsl:otherwise>#<xsl:value-of
                select="."/></xsl:otherwise></xsl:choose></xsl:attribute>
            <xsl:if test="$isPrimitiveType">
                <xsl:attribute name="target">_blank</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="."/>
            <xsl:if test="$isPrimitiveType">
                <i class="fa fa-external-link"/>
            </xsl:if>
        </a>
    </xsl:template>

    <!--
     Utility di visualizzazione
     https://sourceforge.net/projects/xs3p/
     -->

    <xsl:template match="*" mode="html">
        <xsl:call-template name="WriteHtmlElement">
            <xsl:with-param name="element" select="."/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="text()" mode="html">
        <xsl:value-of select="." />
    </xsl:template>

    <xsl:template name="WriteHtmlElement">
        <xsl:param name="element"/>

        <!-- Start Tag -->
        <xsl:text disable-output-escaping="yes">&lt;</xsl:text>
        <xsl:value-of select="local-name($element)"/>
        <!-- Attributes -->
        <xsl:for-each select="$element/@*">
            <xsl:text> </xsl:text>
            <xsl:value-of select="name(.)"/>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="."/>
            <xsl:text>"</xsl:text>
        </xsl:for-each>

        <xsl:choose>
            <xsl:when test="$element/* | $element/text()">
                <!-- Close Start Tag -->
                <xsl:text disable-output-escaping="yes">&gt; </xsl:text>
                <!-- Content -->
                <xsl:apply-templates select="$element/* | $element/text()" mode="html"/>
                <!-- End Tag -->
                <xsl:text disable-output-escaping="yes">&lt;/</xsl:text>
                <xsl:value-of select="local-name($element)"/>
                <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <!-- Close Start Tag -->
                <xsl:text disable-output-escaping="yes">/></xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


</xsl:stylesheet>
